Package: Rapp
Title: Easily Build Command Line Applications
Version: 0.4.1
Authors@R: 
    person("Tomasz", "Kalinowski", role = c("aut", "cre"),
           email = "tomasz@posit.co")
Description: Run simple 'R' scripts as command line applications, with
  automatic robust and convenient support for command line arguments.
  This package provides 'Rapp', an alternative 'R' front-end similar to 
  'Rscript', that enables this.
License: MIT + file LICENSE
URL: https://github.com/r-lib/Rapp
BugReports: https://github.com/r-lib/Rapp/issues
Encoding: UTF-8
Suggests: testthat (>= 3.1.0), withr
Config/testthat/edition: 3
Config/testthat/parallel: true
Config/testthat/start-first: help-snapshots, basics
Imports: yaml12
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-08-24 19:17:53 UTC; tomasz
Author: Tomasz Kalinowski [aut, cre]
Maintainer: Tomasz Kalinowski <tomasz@posit.co>
Repository: CRAN
Date/Publication: 2026-08-24 19:50:02 UTC
Built: R 4.5.2; ; 2026-08-24 22:34:23 UTC; unix
